searchNodes=[{"ref":"Unicode.html","title":"Unicode","type":"module","doc":"Functions to introspect the Unicode character database and to provide fast codepoint lookups."},{"ref":"Unicode.html#alphabetic?/1","title":"Unicode.alphabetic?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to the Derived Core Property Alphabetic otherwise returns false. These are all characters that are usually used as representations of letters/syllabes/ in words/sentences. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.alphabetic?(?a) true iex&gt; Unicode.alphabetic?(&quot;A&quot;) true iex&gt; Unicode.alphabetic?(&quot;Elixir&quot;) true iex&gt; Unicode.alphabetic?(&quot;الإكسير&quot;) true iex&gt; Unicode.alphabetic?(&quot;foo, bar&quot;) # comma and whitespace false iex&gt; Unicode.alphabetic?(&quot;42&quot;) false iex&gt; Unicode.alphabetic?(&quot;龍王&quot;) true iex&gt; Unicode.alphabetic?(&quot;∑&quot;) # Summation, ∑ false iex&gt; Unicode.alphabetic?(&quot;Σ&quot;) # Greek capital letter sigma, Σ true"},{"ref":"Unicode.html#alphanumeric?/1","title":"Unicode.alphanumeric?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) are either alphabetic?/1 or numeric?/1 otherwise returns false. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.alphanumeric? &quot;1234&quot; true iex&gt; Unicode.alphanumeric? &quot;KeyserSöze1995&quot; true iex&gt; Unicode.alphanumeric? &quot;3段&quot; true iex&gt; Unicode.alphanumeric? &quot;dragon@example.com&quot; false"},{"ref":"Unicode.html#block/1","title":"Unicode.block/1","type":"function","doc":"Returns the block name of a codepoint or the list of block names for each codepoint in a string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom block name in the case of a string, a list of atom block names for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.block ?ä :latin_1_supplement iex&gt; Unicode.block ?A :basic_latin iex&gt; Unicode.block &quot;äA&quot; [:latin_1_supplement, :basic_latin]"},{"ref":"Unicode.html#cased?/1","title":"Unicode.cased?/1","type":"function","doc":"Returns either true if the codepoint has the :cased property or false. The :cased property means that this character has at least an upper and lower representation and possibly a titlecase representation too. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.cased? ?ယ false iex&gt; Unicode.cased? ?A true"},{"ref":"Unicode.html#category/1","title":"Unicode.category/1","type":"function","doc":"Returns the Unicode category for a codepoint or a list of categories for a string. Argument codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom representing one of the categories listed below in the case of a string, a list representing the category for each codepoint in the string Notes THese categories match the names of the Unicode character classes used in various regular expression engine. The full list of categories is: CategoryMatches :COther :CcControl :CfFormat :CnUnassigned :CoPrivate use :CsSurrogate :LLetter :LlLower case letter :LmModifier letter :LoOther letter :LtTitle case letter :LuUpper case letter :MMark :McSpacing mark :MeEnclosing mark :MnNon-spacing mark :NNumber :NdDecimal number :NlLetter number :NoOther number :PPunctuation :PcConnector punctuation :PdDash punctuation :PeClose punctuation :PfFinal punctuation :PiInitial punctuation :PoOther punctuation :PsOpen punctuation :SSymbol :ScCurrency symbol :SkModifier symbol :SmMathematical symbol :SoOther symbol :ZSeparator :ZlLine separator :ZpParagraph separator :ZsSpace separator Note too that the group level categories like :L, :M, :S and so on are not assigned to any codepoint. They can only be identified by combining the results for each of the subsidiary categories. Examples iex&gt; Unicode.category ?ä :Ll iex&gt; Unicode.category ?A :Lu iex&gt; Unicode.category ?🧐 :So iex&gt; Unicode.category ?+ :Sm iex&gt; Unicode.category ?1 :Nd iex&gt; Unicode.category &quot;äA&quot; [:Ll, :Lu]"},{"ref":"Unicode.html#class/1","title":"Unicode.class/1","type":"function","doc":"See Unicode.Category.category/1."},{"ref":"Unicode.html#digits?/1","title":"Unicode.digits?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to Unicode category :Nd otherwise returns false. This group of characters represents the decimal digits zero through nine (0..9) and the equivalents in non-Latin scripts. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples"},{"ref":"Unicode.html#emoji?/1","title":"Unicode.emoji?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) are emoji otherwise returns false. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.emoji? &quot;🧐🤓🤩🤩️🤯&quot; true"},{"ref":"Unicode.html#lowercase?/1","title":"Unicode.lowercase?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Ll otherwise returns false. Notice that there are many languages that do not have a distinction between cases. Their characters are not included in this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.lowercase?(?a) true iex&gt; Unicode.lowercase?(&quot;A&quot;) false iex&gt; Unicode.lowercase?(&quot;Elixir&quot;) false iex&gt; Unicode.lowercase?(&quot;léon&quot;) true iex&gt; Unicode.lowercase?(&quot;foo, bar&quot;) false iex&gt; Unicode.lowercase?(&quot;42&quot;) false iex&gt; Unicode.lowercase?(&quot;Σ&quot;) false iex&gt; Unicode.lowercase?(&quot;σ&quot;) true"},{"ref":"Unicode.html#math?/1","title":"Unicode.math?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Sm otherwise returns false. These are all characters whose primary usage is in mathematical concepts (and not in alphabets). Notice that the numerical digits are not part of this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.math?(?=) true iex&gt; Unicode.math?(&quot;=&quot;) true iex&gt; Unicode.math?(&quot;1+1=2&quot;) # Digits do not have the `:math` property. false iex&gt; Unicode.math?(&quot;परिस&quot;) false iex&gt; Unicode.math?(&quot;∑&quot;) # Summation, \\u2211 true iex&gt; Unicode.math?(&quot;Σ&quot;) # Greek capital letter sigma, \\u03a3 false"},{"ref":"Unicode.html#numeric?/1","title":"Unicode.numeric?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to Unicode categories :Nd, :Nl and :No otherwise returns false. This group of characters represents the decimal digits zero through nine (0..9) and the equivalents in non-Latin scripts. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.numeric?(&quot;65535&quot;) true iex&gt; Unicode.numeric?(&quot;42&quot;) true iex&gt; Unicode.numeric?(&quot;lapis philosophorum&quot;) false"},{"ref":"Unicode.html#properties/1","title":"Unicode.properties/1","type":"function","doc":"Returns the list of properties of each codepoint in a given string or the list of properties for a given string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom list of properties in the case of a string, a list of atom lisr for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.properties 0x1bf0 [:alphabetic, :case_ignorable] iex&gt; Unicode.properties ?A [:alphabetic, :uppercase, :cased] iex&gt; Unicode.properties ?+ [:math] iex&gt; Unicode.properties &quot;a1+&quot; [[:alphabetic, :lowercase, :cased], [:numeric, :emoji], [:math]]"},{"ref":"Unicode.html#script/1","title":"Unicode.script/1","type":"function","doc":"Returns the script name of a codepoint or the list of block names for each codepoint in a string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, a string script name in the case of a string, a list of string script names for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.script ?ä &quot;latin&quot; iex&gt; Unicode.script ?خ &quot;arabic&quot; iex&gt; Unicode.script ?अ &quot;devanagari&quot; iex&gt; Unicode.script ?א &quot;hebrew&quot; iex&gt; Unicode.script ?Ж &quot;cyrillic&quot; iex&gt; Unicode.script ?δ &quot;greek&quot; iex&gt; Unicode.script ?ก &quot;thai&quot; iex&gt; Unicode.script ?ယ &quot;myanmar&quot;"},{"ref":"Unicode.html#unaccent/1","title":"Unicode.unaccent/1","type":"function","doc":"Removes accents (diacritical marks) from a string. Arguments string is any String.t Returns A string with all diacritical marks removed Notes The string is first normalised to :nfd form and then all characters in the block :comnbining_diacritical_marks is removed from the string Example iex&gt; Unicode.unaccent(&quot;Et Ça sera sa moitié.&quot;) &quot;Et Ca sera sa moitie.&quot;"},{"ref":"Unicode.html#uppercase?/1","title":"Unicode.uppercase?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Lu otherwise returns false. Notice that there are many languages that do not have a distinction between cases. Their characters are not included in this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.uppercase?(?a) false iex&gt; Unicode.uppercase?(&quot;A&quot;) true iex&gt; Unicode.uppercase?(&quot;Elixir&quot;) false iex&gt; Unicode.uppercase?(&quot;CAMEMBERT&quot;) true iex&gt; Unicode.uppercase?(&quot;foo, bar&quot;) false iex&gt; Unicode.uppercase?(&quot;42&quot;) false iex&gt; Unicode.uppercase?(&quot;Σ&quot;) true iex&gt; Unicode.uppercase?(&quot;σ&quot;) false"},{"ref":"Unicode.html#version/0","title":"Unicode.version/0","type":"function","doc":"Returns the version of Unicode in Cldr.Unicode."},{"ref":"Unicode.html#t:codepoint/0","title":"Unicode.codepoint/0","type":"type","doc":""},{"ref":"Unicode.html#t:codepoint_or_string/0","title":"Unicode.codepoint_or_string/0","type":"type","doc":""},{"ref":"Unicode.Guards.html","title":"Unicode.Guards","type":"module","doc":"Defines a set of guards that can be used with Elixir functions. Each guard operates on a UTF8 codepoint since the permitted operators in a guard clause are restricted to simple comparisons that do not include string comparators. The data that underpins these guards is generated from the Unicode character database and therefore includes a broad range of scripts well beyond the basic ASCII definitions."},{"ref":"Unicode.Guards.html#is_currency_symbol/1","title":"Unicode.Guards.is_currency_symbol/1","type":"macro","doc":"Guards whether a UTF8 codepoint is a currency symbol character."},{"ref":"Unicode.Guards.html#is_digit/1","title":"Unicode.Guards.is_digit/1","type":"macro","doc":"Guards whether a UTF8 codepoint is a digit character. This guard will match any digit character from any Unicode script, not only the ASCII decimal digits."},{"ref":"Unicode.Guards.html#is_lower/1","title":"Unicode.Guards.is_lower/1","type":"macro","doc":"Guards whether a UTF8 codepoint is a lower case character. The match is for any UTF8 character that is defined in Unicode to be an lower case character in any script."},{"ref":"Unicode.Guards.html#is_upper/1","title":"Unicode.Guards.is_upper/1","type":"macro","doc":"Guards whether a UTF8 codepoint is an upper case character. The match is for any UTF8 character that is defined in Unicode to be an upper case character in any script."},{"ref":"Unicode.Guards.html#is_whitespace/1","title":"Unicode.Guards.is_whitespace/1","type":"macro","doc":"Guards whether a UTF8 codepoint is a whitespace symbol character."},{"ref":"readme.html","title":"Cldr Unicode","type":"extras","doc":"Cldr Unicode Functions to return information about Unicode codepoints. The information functions are heavily inspired by @qqwy&#39;s elixir-unicode package and compatibility with some of the api is represented by including some of the doctests from that package. See the documentation and functions in Unicode."},{"ref":"license.html","title":"License","type":"extras","doc":"License Copyright 2018 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."},{"ref":"changelog.html","title":"Changelog for Unicode v1.0.0","type":"extras","doc":"Changelog for Unicode v1.0.0 This is the changelog for Unicode v1.0.0 released on November 14th, 2019. For older changelogs please consult the release tag on GitHub Breaking Changes Rename the module prefix to Unicode since this package is not linked in any way to the Cldr family. The hex package is renamed to ex_unicode. Changelog for Cldr Unicode v0.7.1 This is the changelog for Unicode v0.7.1 released on November 12th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes count/1 for blocks, scripts and categories Replace deprecated String.normalize/2 with :unicode.characters_to_nfd_binary/ for OTP release 20 and later. Changelog for Cldr Unicode v0.7.0 This is the changelog for Unicode v0.7.0 released on November 12th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Add is_whitespace/1 guard generator Changelog for Cldr Unicode v0.6.0 This is the changelog for Unicode v0.6.0 released on October 22nd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Update to Emoji 12.1 Changelog for Cldr Unicode v0.5.0 This is the changelog for Unicode v0.5.0 released on May 12th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Update to Unicode 12.1 Changelog for Cldr Unicode v0.4.0 This is the changelog for Unicode v0.4.0 released on April 30th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Unicode.unaccent/1 Breaking Changes Block names are now atoms instead of strings Changelog for Cldr Unicode v0.3.0 This is the changelog for Unicode v0.3.0 released on March 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updated to Unicode version 12 Changelog for Cldr Unicode v0.2.0 This is the changelog for Unicode v0.2.0 released on February 24th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Moves the public API to the Cldr.Unicode module. Updates and adds documentation to all public functions. Removes the text annotations from the compiled functions which materially reduces the size of the beam files. Changelog for Cldr Unicode v0.1.0 This is the changelog for Unicode v0.1.0 released on February 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Initial release"}]